ChangeLog
=========

0.1.3
-----

* Sorted app list.
* Additional context variables like app, cwd, leaf, rel_path and full path in templates.

0.1.2
-----

* Return 404 for ignored file.

0.1.1
-----

* Security hole, allowing to read any file, was fixed.
* Return 404 for non existent files.

0.1.0
-----

* First version with simple templates and pygments support.
